@@ -35,7 +35,7 @@ TEST_VM_NUM_NODES=1
 DOWNLOAD_CUSTOM_DEPLOY_IMAGE=true
 TESTING_USER=cirros
 TEST_PLAYBOOK="test-bifrost.yaml"
-USE_INSPECTOR=true
+USE_INSPECTOR=${USE_INSPECTOR:-false}
 INSPECT_NODES=true
 INVENTORY_DHCP=false
 INVENTORY_DHCP_STATIC_IP=false
@@ -80,6 +80,13 @@ if [ ${DOWNLOAD_CUSTOM_DEPLOY_IMAGE} = "true" ] && [ ! -f "$HOME/.ssh/id_ecdsa.p
     ssh-keygen -t ECDSA -f "$HOME/.ssh/id_ecdsa" -N ""
 fi
 
+# Install lshw to collect info at the end of the test
+if which rpm &> /dev/null; then
+    sudo dnf install -y lshw
+elif which apt &> /dev/null; then
+    sudo apt install -y lshw
+fi
+
 # Note(cinerama): activate is not compatible with "set -u";
 # disable it just for this line.
 set +u
@@ -90,9 +97,9 @@ ANSIBLE_PYTHON_INTERP=${VENV}/bin/python3
 
 # Adjust options for DHCP, VM, or Keystone tests
 if [ ${USE_DHCP} = "true" ]; then
-    ENABLE_INSPECTOR=false
     INSPECT_NODES=false
     TEST_VM_NUM_NODES=3
+    VM_DISK=4
     INVENTORY_DHCP=true
     INVENTORY_DHCP_STATIC_IP=true
     WRITE_INTERFACES_FILE=false
@@ -101,7 +108,6 @@ elif [ ${BUILD_IMAGE} = "true" ]; then
     DOWNLOAD_CUSTOM_DEPLOY_IMAGE=false
     TESTING_USER=root
     VM_MEMORY_SIZE="4096"
-    ENABLE_INSPECTOR=false
     INSPECT_NODES=false
     DOWNLOAD_IPA=false
     CREATE_IPA_IMAGE=true
